@@ -1,5 +1,6 @@
+/* $Id: ibuf_open.c 616 2005-08-19 20:11:01Z bruce $ */
 #include <unistd.h>
-#include "iobuf.h"
+#include "ibuf.h"
 
 /** Initialize an \c ibuf by opening a file for reading. */
 int ibuf_open(ibuf* in, const char* filename, unsigned bufsize)
