@@ -1,6 +1,7 @@
+/* $Id: obuf_putns.c 616 2005-08-19 20:11:01Z bruce $ */
 #include <stdarg.h>
 #include <string.h>
-#include "iobuf.h"
+#include "obuf.h"
 
 /** Write N C strings to the \c obuf */
 int obuf_putns(obuf* out, unsigned int count, ...)
